@@ -17,12 +17,15 @@
 #'   c(2,4)} for comparing the second to the fourth phase. Phases could be
 #'   combined by providing a list with two elements. E.g., \code{phases = list(A
 #'   = c(1,3), B = c(2,4))} will compare phases 1 and 3 (as A) against 2 and 4
-#'   (as B). Default is \code{phases = c("A","B")}.
-#' @param model Model used for calculating the slope parameter (see Huitema &
+#'   (as B). Default is \code{phases = c(1,2)}.
+#' @param model Model used for calculating the dummy parameters (see Huitema &
 #'   McKean, 2000). Default is \code{model = "W"}. Possible values are:
 #'   \code{"B&L-B"}, \code{"H-M"}, \code{"W"}, and deprecated \code{"JW"}.
-#' @param contrast Either "first" or "preceding". "first" contrasts all 
-#'   phase-effects to the first phase and "preceding" to the preceding phase.
+#' @param contrast Sets contrast_level and contrast_slope. Either "first", "preceding" or a contrast matrix.
+#' @param contrast_level Either "first", "preceding" or a contrast matrix. If NA
+#' contrast_level is a copy of contrast.
+#' @param contrast_slope Either "first", "preceding" or a contrast matrix. If NA
+#' contrast_level is a copy of contrast.
 #' @param trend A logical indicating if a trend parameters is included in the
 #'   model.
 #' @param level A logical indicating if a level parameters is included in the
@@ -31,6 +34,7 @@
 #'   model.
 #' @param ... Further arguments passed to the function.
 .inheritParams <- function(data, scdf, dvar, mvar, pvar, decreasing, 
-                           phases, model, contrast, trend, level, slope, ...) {
+                           phases, model, contrast, contrast_level, contrast_slope,
+                           trend, level, slope, ...) {
   
 } 
\ No newline at end of file
