@@ -67,14 +67,14 @@
 #'   slope = list(A1 = 0, B1 = 0.0, A2 = 0, B2 = 0.0),
 #'   trend = 0.0)
 #' dat <- random_scdf(design = A1B1A2B2, seed = 123)
-#' plm(dat, model = "JW")
+#' plm(dat, contrast = "preceding")
 #' 
 #' ## no slope effects were found. Therefore, you might want to the drop slope 
 #' ## estimation:
-#' plm(dat, slope = FALSE, model = "JW")
+#' plm(dat, slope = FALSE, contrast = "preceding")
 #' 
 #' ## and now drop the trend estimation as well
-#' plm(dat, slope = FALSE, trend = FALSE, model = "JW")
+#' plm(dat, slope = FALSE, trend = FALSE, contrast = "preceding")
 #' 
 #' ## A poisson regression
 #' example_A24 %>% 
@@ -97,6 +97,8 @@ plm <- function(data, dvar, pvar, mvar,
                 level = TRUE, 
                 slope = TRUE,
                 contrast = "first",
+                contrast_level = NA,
+                contrast_slope = NA,
                 formula = NULL, 
                 update = NULL, 
                 na.action = na.omit,
@@ -105,7 +107,6 @@ plm <- function(data, dvar, pvar, mvar,
                 dvar_percentage = FALSE,
                 ...) {
   
-  if (family != "gaussian") r_squared = FALSE
   
   # set defaults attributes
   if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv) 
@@ -117,36 +118,47 @@ plm <- function(data, dvar, pvar, mvar,
   scdf_attr(data, .opt$mt) <- mvar
   
   data <- .prepare_scdf(data, na.rm = TRUE)
+
+  if (is.na(contrast_level)) contrast_level <- contrast
+  if (is.na(contrast_slope)) contrast_slope <- contrast
+  
+  if (model == "JW") {
+    contrast_level <- "preceding"
+    contrast_slope <- "preceding"
+    model <- "B&L-B"
+  }
+  
+  if (family != "gaussian") r_squared = FALSE
   
   original_attr <- attributes(data)[[.opt$scdf]]
   
+
   N <- length(data)
   
-  if (model == "JW") {
-    model <- "B&L-B"
-    contrast <- "preceding"
-  }
-  
-  .start_check() %>%
-    .check(N == 1, "Procedure could not be applied to more than one case ",
-                   "(use hplm instead).") %>%
-    .check(family == "gaussian" || AR == 0, 
+  start_check() %>%
+    check(N == 1, "Procedure could not be applied to more than one case ",
+                  "(use hplm instead).") %>%
+    check(family == "gaussian" || AR == 0, 
            "family is not 'gaussian' but AR is set.") %>%
-    .check_not(family == "binomial" && is.null(var_trials),
+    check_not(family == "binomial" && is.null(var_trials),
                "family = 'binomial' but 'var_trials' not defined.") %>%
-    .check_in(model, c("H-M", "B&L-B", "W")) %>%
-    .check_in(contrast, c("first", "preceding")) %>%
-    .end_check()
+    check_in(model, c("H-M", "B&L-B", "W")) %>%
+    #.check_in(contrast, c("first", "preceding")) %>%
+    end_check()
   
   # formula definition ------------------------------------------------------
   
-  tmp_model <- .add_model_dummies(data = data, model = model, contrast=contrast)
+  tmp_model <- .add_model_dummies(
+    data = data, model = model, 
+    contrast_level = contrast_level, contrast_slope = contrast_slope
+  )
+
   data  <- tmp_model$data[[1]]
   
   if(is.null(formula)) {
     tmp <- .create_fixed_formula(
       dvar, mvar, slope, level, trend, 
-      tmp_model$VAR_PHASE, tmp_model$VAR_INTER
+      tmp_model$var_phase, tmp_model$var_inter
     ) 
     formula <- as.formula(tmp)
   } 
@@ -257,7 +269,7 @@ plm <- function(data, dvar, pvar, mvar,
   out <- list(
     formula = formula_full, 
     model = model, 
-    contrast = contrast,
+    contrast = list(level = contrast_level, slope = contrast_slope),
     F.test = F_test, 
     r.squares = r_squares, 
     ar = AR, 
