@@ -6,6 +6,6 @@ print.sc_trend <- function(x, digits = 3, ...) {
   cat("Trend for each phase\n\n")
   print(x$trend)
   cat("\n")
-  cat("Note. Measurement-times start at", 1 + x$offset, " for each phase\n")
+  cat("Note. Measurement-times start at", x$first_mt, " for each phase\n")
   .note_vars(x)
 }
