@@ -1,20 +1,25 @@
 #' Rank-transformation of single-case data files
-#' 
+#'
+#' *This function is superseded by the more versatile 
+#' \code{\link{transform.scdf}} function.*
+#'
 #' @inheritParams .inheritParams
-#' @param var A string or string vector with the names of the variables to be ranked.
-#' @param grand If TRUE, ranks will be calculated across all cases. If FALSE ranks are calculated within each case.
-#' @param ... Additional paramters passed to the \code{\link{rank}} function.
-#' @return An \code{scdf} object where the values of the variable(s) are replaced with ranks.
+#' @param var A string or string vector with the names of the variables to be
+#'   ranked.
+#' @param grand If TRUE, ranks will be calculated across all cases. If FALSE
+#'   ranks are calculated within each case.
+#' @param ... Additional parameters passed to the \code{\link{rank}} function.
+#' @return An \code{scdf} object where the values of the variable(s) are
+#'   replaced with ranks.
 #' @author Juergen Wilbert
 #' @family data manipulation functions
 #' @examples
-#' Huber2014_rank <- ranks(Huber2014, var = "compliance")
-#' plot(Huber2014_rank, style = "grid2")
+#' ranks(Huber2014, var = "compliance")
 #' @export
 
 ranks <- function(data, var, grand = TRUE, ...) {
   
-  if(isFALSE(grand)) {
+  if(identical(grand, FALSE)) {
     for(i in 1:length(data)) {
       for(v in var)
         data[[i]][, v] <- rank(data[[i]][, v], na.last = "keep", ...)
